@@ -1,6 +1,5 @@
 from django.views.generic import ListView
-
-import settings
+from django.conf import settings
 
 from . import models
 from .forms import FAQSearchForm
